@@ -35,7 +35,7 @@ class Formatter(t.Protocol):
 class ClypiFormatter:
     boxed: bool = True
     show_option_types: bool = False
-    show_forwarded_options: bool = True
+    show_inherited_options: bool = True
     normalize_dots: t.Literal[".", ""] | None = ""
 
     @cached_property
@@ -137,7 +137,7 @@ class ClypiFormatter:
 
         # Group by option group
         for o in options:
-            if o.forwarded and not self.show_forwarded_options:
+            if o.inherited and not self.show_inherited_options:
                 continue
             groups[o.group].append(o)
 
@@ -216,16 +216,16 @@ class ClypiFormatter:
         prefix = self.theme.usage("Usage:")
         command_str = self.theme.usage_command(" ".join(full_command))
 
-        option = self.theme.usage_args(" [OPTIONS]") if options else ""
-        command = self.theme.usage_args(" COMMAND") if subcommands else ""
-
         positionals_str: list[str] = []
         for pos in positionals:
             name = self._format_positional_with_mod(pos)
             positionals_str.append(self.theme.usage_args(name))
         positional = " " + " ".join(positionals_str) if positionals else ""
 
-        return f"{prefix} {command_str}{option}{command}{positional}"
+        option = self.theme.usage_args(" [OPTIONS]") if options else ""
+        command = self.theme.usage_args(" COMMAND") if subcommands else ""
+
+        return f"{prefix} {command_str}{positional}{option}{command}"
 
     def _format_description(self, description: str | None) -> str | None:
         if not description:
