@@ -172,23 +172,23 @@ class _CommandMeta(type):
     def inherit(self, parent: type[Command]) -> list[str]:
         """
         This function is called by the parent command during parsing to configure
-        inherited fields through forwarding and the parenthood relationship so that the
-        full command is displayed properly.
+        inherited fields and the parenthood relationship so that the full command
+        is displayed properly.
 
         Returns the list of inherited fields
         """
         setattr(self, CLYPI_PARENTS, parent.full_command())
 
-        # For forwarded args, configure them with the parent's configs
+        # For inherited args, configure them with the parent's configs
         options = self.options()
         inherited: list[str] = []
         for opt, opt_config in parent.options().items():
-            if opt not in options or not options[opt].forwarded:
+            if opt not in options or not options[opt].inherited:
                 continue
             options[opt] = dataclasses.replace(
                 opt_config,
-                # Keep forwarding and group config
-                forwarded=True,
+                # Keep inherited and group config
+                inherited=True,
                 group=options[opt].group or opt_config.group,
             )
             inherited.append(opt)
@@ -349,6 +349,20 @@ class Command(metaclass=_CommandMeta):
         doc = inspect.getdoc(cls) or ""
         return doc.replace("\n", " ")
 
+    async def pre_run_hook(self) -> None:
+        """
+        This function will execute on every command and subcommand right
+        before running it.
+        """
+        pass
+
+    async def post_run_hook(self, exception: Exception | None) -> None:
+        """
+        This function will execute on every command and subcommand right
+        after running it.
+        """
+        pass
+
     async def run(self) -> None:
         """
         This function is where the business logic of your command
@@ -360,18 +374,39 @@ class Command(metaclass=_CommandMeta):
         self.print_help()
 
     @t.final
-    async def astart(self) -> None:
-        if subcommand := getattr(self, "subcommand", None):
-            return await subcommand.astart()
+    async def astart(self) -> Exception | None:
+        exc: Exception | None = None
 
-        try:
-            return await self.run()
-        except get_config().nice_errors as e:
-            print_traceback(e)
+        # If the class has a subcommand, traverse into the child cmd
+        if subcommand := getattr(self, "subcommand", None):
+            await self.pre_run_hook()
+            try:
+                exc = await subcommand.astart()
+            except Exception as e:
+                exc = e
+                raise
+            finally:
+                await self.post_run_hook(exc)
+
+        # Otherwise this is the command to run, run it
+        else:
+            await self.pre_run_hook()
+            try:
+                await self.run()
+            except get_config().nice_errors as e:
+                exc = e
+                print_traceback(e)
+            except Exception as e:
+                exc = e
+                raise
+            finally:
+                await self.post_run_hook(exc)
+
+        return exc
 
     @t.final
-    def start(self) -> None:
-        asyncio.run(self.astart())
+    def start(self) -> Exception | None:
+        return asyncio.run(self.astart())
 
     @t.final
     @classmethod
@@ -471,7 +506,7 @@ class Command(metaclass=_CommandMeta):
         and subcommands until the iterator is complete.
 
         When we encounter a subcommand, we parse all the types, then try to keep parsing the
-        subcommand whilst we assign all forwarded types.
+        subcommand whilst we assign all inherited types.
         """
         parent_attrs = parent_attrs or {}
 
@@ -556,7 +591,7 @@ class Command(metaclass=_CommandMeta):
                     parsed_kwargs[field] = field_conf.parser(unparsed[field])
 
                 # If the field comes from a parent command, use that
-                elif field_conf.forwarded and field in parent_attrs:
+                elif field_conf.inherited and field in parent_attrs:
                     parsed_kwargs[field] = parent_attrs[field]
 
                 # If the field was not provided but we can defer prompting for the
@@ -588,7 +623,7 @@ class Command(metaclass=_CommandMeta):
 
         # Parse the subcommand passing in the parsed types
         if subcommand:
-            # Configure parenthood and forwarded args
+            # Configure parenthood and inherited args
             inherited_fields = subcommand.inherit(cls)
 
             # Parse the subcommand
