@@ -1,14 +1,15 @@
 from __future__ import annotations
 
-import v6e as v
-
 import clypi
-from clypi import colors
+import clypi.parsers as cp
 
 
-def _validate_earth_age(x: int) -> None:
-    if x != 4_543_000_000:
-        raise ValueError("The Earth is 4.543 billion years old. Try 4543000000.")
+def _validate_earth_age(x: str | list[str]) -> int:
+    if isinstance(x, str):
+        x_int = int(x)
+        if x_int == 4_543_000_000:
+            return x_int
+    raise ValueError("The Earth is 4.543 billion years old. Try 4543000000.")
 
 
 def main() -> None:
@@ -18,37 +19,32 @@ def main() -> None:
     # Default values
     is_cool = clypi.confirm("Is clypi cool?", default=True)
 
-    # Custom types with parsing using v6e
+    # Custom types with parsing
     age = clypi.prompt(
         "How old are you?",
-        parser=int,
+        parser=cp.Int(gte=18),
         hide_input=True,
     )
     hours = clypi.prompt(
         "How many hours are there in a day?",
-        parser=v.timedelta() | v.int(),
+        parser=cp.Union(cp.TimeDelta(), cp.Int()),
     )
 
-    # Custom validations using v6e
+    # Custom validations
     earth = clypi.prompt(
         "How old is The Earth?",
-        parser=v.int().custom(_validate_earth_age),
-    )
-    moon = clypi.prompt(
-        "How old is The Moon?",
-        parser=v.int().gte(3).lte(9).multiple_of(3),  # You can chain validations
+        parser=_validate_earth_age,
     )
 
     # -----------
     print()
-    colors.print("🚀 Summary", bold=True, fg="green")
-    answer = colors.styler(fg="magenta", bold=True)
+    clypi.cprint("🚀 Summary", bold=True, fg="green")
+    answer = clypi.Styler(fg="magenta", bold=True)
     print(" ↳  Name:", answer(name))
     print(" ↳  Clypi is cool:", answer(is_cool))
     print(" ↳  Age:", answer(age))
     print(" ↳  Hours in a day:", answer(hours), f"({type(hours).__name__})")
     print(" ↳  Earth age:", answer(earth))
-    print(" ↳  Moon age:", answer(moon))
 
 
 if __name__ == "__main__":
