@@ -5,10 +5,10 @@ from clypi import Command, arg
 class Install(Command):
     """Install packages into an environment"""
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
 
     async def run(self) -> None:
         clypi.cprint("Running `uv pip install` command...", fg="blue")
@@ -17,10 +17,10 @@ class Install(Command):
 class Uninstall(Command):
     """Uninstall packages from an environment"""
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
 
     async def run(self) -> None:
         clypi.cprint("Running `uv pip uninstall` command...", fg="blue")
@@ -29,10 +29,10 @@ class Uninstall(Command):
 class Freeze(Command):
     """List, in requirements format, packages installed in an environment"""
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
 
     async def run(self) -> None:
         clypi.cprint("Running `uv pip freeze` command...", fg="blue")
@@ -41,10 +41,10 @@ class Freeze(Command):
 class List(Command):
     """List, in tabular format, packages installed in an environment"""
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
 
     async def run(self) -> None:
         clypi.cprint("Running `uv pip list` command...", fg="blue")
@@ -55,7 +55,7 @@ class Pip(Command):
 
     subcommand: Install | Uninstall | Freeze | List
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
