@@ -12,10 +12,10 @@ class Remove(Command):
         False, help="Remove the packages from the development dependency group"
     )
 
-    # Forwarded opts
-    quiet: bool = arg(...)
-    version: bool = arg(...)
-    no_cache: bool = arg(...)
+    # Inherited opts
+    quiet: bool = arg(inherited=True)
+    version: bool = arg(inherited=True)
+    no_cache: bool = arg(inherited=True)
 
     async def run(self) -> None:
         clypi.cprint("Running `uv remove` command...", fg="blue")
