@@ -6,8 +6,7 @@ from pathlib import Path
 import pytest
 from typing_extensions import override
 
-from clypi import Command, Positional, arg
-from clypi._configuration import get_config
+from clypi import Command, Positional, arg, get_config
 
 
 def parametrize(args: str, cases: list[tuple[t.Any, ...]]):
@@ -21,7 +20,7 @@ get_config().help_on_fail = False
 
 
 class ExampleSub(Command):
-    pos2: Positional[tuple[str | Path, ...]]
+    pos2: Positional[tuple[str, ...]]
     flag2: bool = False
     option2: int = 5
 
